@@ -2,6 +2,8 @@
 
 from typing import Any, Dict, Optional
 
+from kameleoon.defaults import DEFAULT_TIMEOUT_MILLISECONDS
+
 
 class KameleoonClientConfiguration:
     """Client configuration which can be used instead of external configuration file"""
@@ -9,7 +11,7 @@ class KameleoonClientConfiguration:
     # pylint: disable=R0913
     def __init__(self,
                  actions_configuration_refresh_interval: int = 60,
-                 default_timeout: int = 2000,
+                 default_timeout: int = DEFAULT_TIMEOUT_MILLISECONDS,
                  visitor_data_maximum_size: int = 500,
                  environment: Optional[str] = None,
                  multi_threading: bool = False):
