@@ -25,17 +25,17 @@ class Variable:
 
     def __init__(self, dict_json: Dict[str, Any]):
         self.key: str = dict_json.get("key", "")
-        self.type: str = dict_json.get("type", "")
-        self.value: Union[bool, float, str] = dict_json.get("value", False)
+        self.__type: str = dict_json.get("type", "")
+        self.__value: Union[bool, float, str] = dict_json.get("value", False)
 
     def get_value(self) -> Union[bool, float, str, List[Any], Dict[str, Any], None]:
         """Returns a bare value of variable"""
-        if self.type in (
+        if self.__type in (
             Variable.Type.BOOLEAN.value,
             Variable.Type.NUMBER.value,
             Variable.Type.STRING.value,
         ):
-            return self.value
-        if self.type == Variable.Type.JSON.value and isinstance(self.value, str):
-            return json.loads(self.value)
+            return self.__value
+        if self.__type == Variable.Type.JSON.value and isinstance(self.__value, str):
+            return json.loads(self.__value)
         return None
