@@ -5,7 +5,7 @@ import math
 import sys
 from http.cookies import SimpleCookie
 from secrets import token_urlsafe
-from typing import Dict, Any, Union
+from typing import Dict, Any, Optional, Union
 
 from kameleoon.defaults import (
     KAMELEOON_COOKIE_VALUE_LENGTH,
@@ -23,12 +23,14 @@ def obtain_hash_double(
     return _obtain_hash_double(visitor_code, respool_times, container_id)
 
 
-def obtain_hash_double_v2(
-    visitor_code: str, container_id: Union[str, int] = "", suffix: str = ""
+def obtain_hash_double_rule(
+    visitor_code: str, container_id: int, respool_time: Optional[int] = None
 ) -> float:
     """Calculate the hash value for feature flag v2 for a given visitor_code"""
     return _obtain_hash_double(
-        visitor_code=visitor_code, container_id=container_id, suffix=suffix
+        visitor_code=visitor_code,
+        container_id=container_id,
+        suffix=str(respool_time) if respool_time else "",
     )
 
 
