@@ -1,12 +1,12 @@
 """ Kameleoon Real Time Configuration Service """
 import json
-from multiprocessing import get_logger
 from typing import Any, Callable, Dict, Optional
 import sseclient
 import requests
+from kameleoon.helpers.logger import Logger
 
 
-from kameleoon.helpers.multi_threading import run_in_threads_if_required
+from kameleoon.helpers.multi_threading import run_in_thread
 
 from kameleoon.real_time.real_time_event import RealTimeEvent
 
@@ -20,9 +20,7 @@ class RealTimeConfigurationService:
     (experiments and feature flags) in real time
     """
 
-    def __init__(
-        self, url: str, update_handler: Callable[[RealTimeEvent], None], logger=None
-    ):
+    def __init__(self, url: str, update_handler: Callable[[RealTimeEvent], None], logger=None):
         """
         For RealTimeConfigurationService must be provided an url
         from where it can read the updates
@@ -35,24 +33,17 @@ class RealTimeConfigurationService:
             "Cache-Control": "no-cache",
             "Connection": "Keep-Alive",
         }
-        self.logger = logger or get_logger()
+        self.logger = logger or Logger.shared()
         self.response: Optional[Any] = None
         self._create_sse_client()
 
     def _create_sse_client(self) -> None:
         if not self.need_close:
-            run_in_threads_if_required(
-                background_thread=True,
-                func=self._run_sse_client,
-                args=[],
-                thread_name=KAMELEOON_REAL_TIME_CONFIGURATION_THREAD,
-            )
+            run_in_thread(self._run_sse_client, KAMELEOON_REAL_TIME_CONFIGURATION_THREAD, with_event_loop=True)
 
     def _run_sse_client(self):
         self.logger.debug("Create SSE client")
-        self.response = RealTimeConfigurationService._with_requests(
-            self.url, self.headers
-        )
+        self.response = RealTimeConfigurationService._with_requests(self.url, self.headers)
         client = sseclient.SSEClient(self.response)
         try:
             for message in client.events():
