@@ -1,9 +1,10 @@
 import json
+import time
 
 from django.http import JsonResponse
 from django.apps import apps
 
-from kameleoon.data import CustomData
+from kameleoon.data import CustomData, PageView
 from kameleoon.exceptions import (
     NotAllocated,
     NotTargeted,
@@ -21,6 +22,7 @@ def variation_view(request):
     experiment_id = 135471
     variation_id = None
     try:
+        client.add_data(visitor_code, PageView("https://wer.com/", ""))
         variation_id = client.trigger_experiment(visitor_code, experiment_id)
     except NotAllocated:
         variation_id = None
@@ -86,6 +88,7 @@ def add_data_view(request):
 def flush_view(request):
     kameleoon_cookie = client.get_visitor_code(request.COOKIES, local_ip)
     client.flush()
+    time.sleep(5.0)  # Delay due to possible multi-threading execution of `flush`
     data = {}
     for k, v in client.data.items():
         data[k] = [x.to_dict() for x in v]
